@@ -6,8 +6,9 @@ check.active.constraints <- function(object,tol=1/1000){
 
     i <- which(abs(constraints)<tol)
     A <- object@constraints$ineq.jac(coef(object))
+    U <- rbind(object@ineq,object@ineq)
     
-    list(active.constraints=object@ineq[i,],boundary.value=constraints[i])
+    list(active.constraints=U[i,],boundary.value=constraints[i])
   }
   else{
     list(active.constraints=NULL,boundary.value=NULL)
@@ -17,11 +18,11 @@ check.active.constraints <- function(object,tol=1/1000){
 check.auglag.blm.active.constraints <- function(object){
 
   constraints <- object@fit$lambda
-
+  
   if(any(constraints!=0)){
 
     i <- which(abs(constraints)!=0)
-    U <- object@ineq
+    U <- rbind(object@ineq,object@ineq)
     
     list(active.constraints=U[i,],lambda=constraints[i])
   }
@@ -38,6 +39,7 @@ check.auglag.lexpit.active.constraints <- function(object){
 
     i <- which(abs(constraints)!=0)
     U <- cbind(object@ineq$A,object@ineq$B)
+    U <- rbind(U,U)
     
     list(active.constraints=U[i,],lambda=constraints[i])
   }
@@ -54,6 +56,7 @@ check.lexpit.active.constraints <- function(object,tol=1/1000){
 
     i <- which(abs(constraints)<tol)
     U <- cbind(object@ineq$A,object@ineq$B)
+    U <- rbind(U,U)
     
     list(active.constraints=U[i,],boundary.value=constraints[i])
    }
